#!/bin/bash
# Thomas Reerink
#
# This script adds some non-cmor variables (which thus do not exit in the CMIP6 data request) to the end of the cmor table in question.
#
# This scripts requires no arguments.
#
# Run example:
#  ./add-non-cmor-variables.sh
#

if [ "$#" -eq 0 ]; then

 add_barakuda_variables=True
 

 if [ add_barakuda_variables ]; then
  # calving 	Water Flux into Sea Water From Icebergs
  # taum	Wind Stress Module
  # wspd  	Wind Speed Module
  # precip	Precipitation Flux    

  head --lines=-3 ../resources/tables/CMIP6_Omon.json                                                                                                     >  extended-CMIP6_Omon.json

  echo '        },                                                                                                                     ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '        "calving": {                                                                                                           ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "frequency": "mon",                                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "modeling_realm": "ocean",                                                                                         ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "standard_name": "water_flux_into_sea_water_from_icebergs",                                                        ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "units": "kg m-2 s-1",                                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_methods": "area: mean where sea time: mean",                                                                 ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_measures": "area: areacella",                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "long_name": "Water Flux into Sea Water From Icebergs",                                             	       ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "comment": "",  												       ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json 
  echo '            "dimensions": "longitude latitude time",                                                                           ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "out_name": "calving",                                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "type": "real",                                                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "positive": "",                                                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_min": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_max": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_min_mean_abs": "",                                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_max_mean_abs": ""                                                                                              ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json

  echo '        },                                                                                                                     ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '        "rhopo": {                                                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "frequency": "mon",                                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "modeling_realm": "ocean",                                                                                         ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "standard_name": "potential_dentisty",                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "units": "kg m-3",                                                                                                 ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_methods": "area: mean where sea time: mean",                                                                 ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_measures": "area: areacella",                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "long_name": "Potential Density",                                             	                               ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "comment": "Potential Density",  										       ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json 
  echo '            "dimensions": "longitude latitude olevel time",                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "out_name": "rhopo",                                                                                               ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "type": "real",                                                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "positive": "",                                                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_min": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_max": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_min_mean_abs": "",                                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_max_mean_abs": ""                                                                                              ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  
  echo '        },                                                                                                                     ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '        "taum": {                                                                                                              ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "frequency": "mon",                                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "modeling_realm": "ocean",                                                                                         ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "standard_name": "magnitude_of_surface_downward_stress",                                                           ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "units": "N m-2",                                                                                                  ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_methods": "time: mean",                                                                                      ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_measures": "area: areacella",                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "long_name": "Wind stress module",                                                       			       ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "comment": "Wind stress module",  										       ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json 
  echo '            "dimensions": "longitude latitude time",                                                                           ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "out_name": "taum",                                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "type": "real",                                                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "positive": "down",                                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_min": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_max": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_min_mean_abs": "",                                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_max_mean_abs": ""                                                                                              ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '        },                                                                                                                     ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json

  echo '        "wspd": {                                                                                                              ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "frequency": "mon",                                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "modeling_realm": "ocean",                                                                                         ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "standard_name": "wind_speed",                                               				       ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "units": "m s-1",                                                                                                  ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_methods": "time: mean",                                                                                      ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_measures": "area: areacella",                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "long_name": "Wind speed module",                                              				       ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "comment": "Wind speed module",  										       ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json 
  echo '            "dimensions": "longitude latitude time",                                                                           ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "out_name": "wspd",                                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "type": "real",                                                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "positive": "",                                                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_min": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_max": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_min_mean_abs": "",                                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_max_mean_abs": ""                                                                                              ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json

  echo '        },                                                                                                                     ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '        "precip": {                                                                                                            ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "frequency": "mon",                                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "modeling_realm": "ocean",                                                                                         ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "standard_name": "precipitation_flux",                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "units": "kg m-2 s-1",                                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_methods": "area: mean where sea time: mean",                                                                 ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "cell_measures": "area: areacella",                                                                                ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "long_name": "Precipitation Flux",                                                                                 ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "comment": "Precipitation Flux from nemo",  							               ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json 
  echo '            "dimensions": "longitude latitude time",                                                                           ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "out_name": "precip",                                                                                              ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "type": "real",                                                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "positive": "",                                                                                                    ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_min": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "valid_max": "",                                                                                                   ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_min_mean_abs": "",                                                                                             ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json
  echo '            "ok_max_mean_abs": ""                                                                                              ' | sed 's/\s*$//g' >> extended-CMIP6_Omon.json

  echo '        }'                                                                                                                                         >> extended-CMIP6_Omon.json
  echo '    }'                                                                                                                                             >> extended-CMIP6_Omon.json
  echo '}'                                                                                                                                                 >> extended-CMIP6_Omon.json

  mv -f extended-CMIP6_Omon.json ../resources/tables/CMIP6_Omon.json

 else
    echo '  '
    echo '  Noting done, no set of variables has been selected to add to the tables.'
    echo '  '
 fi

else
    echo '  '
    echo '  This scripts requires no argument:'
    echo '  ' $0
    echo '  '
fi
