#!/usr/bin/env bash

#####################################################################################################################
# Functions for handling modules and environment setup for marenostrum5 platform (inherited and updated from MN4)
# Author: E.Ferrer
#####################################################################################################################

#####################################################################################################################
# Globals:
#   PROJDIR
# Arguments:
#   None
# Returns:
#   None
# Purpose: main function to prepare execution environment for the underlying platform, that basically consist on
#   setting up the modules to be used, common environment variables and the common paths
#####################################################################################################################
function load_platform_environment() {
  # load utils/filesystem libraries for common env functions
  . "${PROJDIR}/platforms/marenostrum5/filesystem.sh"
  . "${PROJDIR}/platforms/marenostrum5/utils.sh"
  #load global environment variables
  setup_modules
  #configure all modules needed for run the job
  setup_environment_vars
  # define all paths needed
  setup_paths
}

#####################################################################################################################
# Globals:
#   None
# Arguments:
#   None
# Returns:
#   None
# Purpose: Prepare the modules needed to execute ece2cmor component for Marenostrum5 platform
#####################################################################################################################
function load_modules_ece2cmor() {
  set +xuve
  module purge
  module load oneapi/2023.2 hdf5/1.14.1-2 pnetcdf/1.12.3 netcdf/2023-06-14 cdo/1.8.2 aec/1.1.2 eccodes/2.34.1 gsl/2.7.1 libexpat/2.6.2 udunits/2.2.28 nco/5.2.2 cdo/1.8.2
  load_python_env
  set -xuve
}

#####################################################################################################################
# Globals:
#   None
# Arguments:
#   None
# Returns:
#   None
# Purpose: load and activate the conda environment with python on Marenostrum5
#####################################################################################################################
function load_python_env() {
  module load miniconda/24.1.2
  source /apps/GPP/MINICONDA/24.1.2/etc/profile.d/conda.sh
  conda activate /gpfs/projects/bsc32/repository/apps/conda_envs/cmor_env_trunk
  export PYTHONPATH=/gpfs/projects/bsc32/repository/apps/conda_envs/cmor_env_trunk/lib/python3.11/site-packages/ece2cmor3:$PYTHONPATH
}

#####################################################################################################################
# Globals:
#   None
# Arguments:
#   None
# Returns:
#   None
# Purpose: Prepare the modules needed to execute the OASIS restart generation script for Marenostrum5 platform
#####################################################################################################################
function load_modules_oas_rsts_gen() {
  set +xuve
  module load hdf5/1.14.1-2 pnetcdf/1.12.3 #dependencies for netcdf
  module load netcdf/2023-06-14
  module load cdo/1.8.2
  module load libexpat/2.6.2
  module load udunits/2.2.28
  module load gsl/2.7.1
  module load nco/5.2.2
  set -xuve
}

#####################################################################################################################
# Globals:
#  PATH, PROJDIR
# Arguments:
#   None
# Returns:
#   None
# Purpose: define the global vars with the path to the grib modules needed to run the ece2cmor module
#####################################################################################################################
function define_paths_ece2cmor() {
  grib_api_path=${ECCODES_ROOT}
  PATH=${grib_api_path}/bin:${PATH}
  export GRIB_BIN_PATH=${grib_api_path}/bin
  export GRIB_DEFINITION_PATH=${PROJDIR}/sources/sources/util/grib_table_126:${grib_api_path}/share/eccodes/definitions
  export GRIB_SAMPLES_PATH=${grib_api_path}/share/eccodes/ifs_samples/grib1
  export PYTHONPATH=${PROJDIR}/ece2cmor/:$PYTHONPATH
  export PYTHONPATH=${PROJDIR}/ece2cmor/ece2cmor3/scripts:$PYTHONPATH
}
